<template>
  <div class="mobile-device">
    <van-tabs color="#469FF7" v-model="tabActiveName" @click="onTabClick">
      <van-tab
        v-for="item in classList"
        :key="item.value"
        :title="item.text"
        :name="item.value"
      />
    </van-tabs>
    <van-pull-refresh
      v-model="refreshing"
      @refresh="onRefresh"
      class="van-hairline--top"
    >
      <van-list
        v-model="loading"
        :finished="finished"
        finished-text="没有更多了"
        :immediate-check="false"
        :offset="100"
        @load="onLoad"
      >
        <div
          v-for="(device, index) in deviceData"
          :key="index"
          class="device van-hairline--bottom"
          :class="{myStyle: index === deviceData.length - 1}"
          @click="handleDetail(device)"
        >
          <div class="device-item">
            <div class="device-item-text">
              <div
                class="device-item-content"
                style="margin-bottom: 6px"
              >
                <div>
                  <div class="device-name">
                    {{ device.deviceName }}
                  </div>
                </div>
                <div class="device-status">
                  <van-tag
                    type="success"
                    v-if="device.dataType == 1"
                  >报警解除
                  </van-tag
                  >
                  <van-tag
                    type="danger"
                    v-if="device.dataType == 0"
                  >报警
                  </van-tag
                  >
                </div>
              </div>
            </div>
            <div class="device-content">
              <!-- <p>采集时间:{{ device.collTime }}</p>
              <p v-if="tabActiveName == '1'">
                  电池电量(%):{{ device.batteryValue }}
              </p>
              <p>设备电压(v):{{ device.batteryVoltage }}</p>
              <p v-if="tabActiveName == '2'">水位高度:{{ device.sdata }}</p> -->

              <p>
                                <span style="color: #333">采集时间：</span
                                >{{ device.collTime }}
              </p>
              <template v-if="tabActiveName == '1'">
                <p>
                                    <span style="color: #333">X轴角度(°)：</span
                                    >{{ device.angleX }}
                </p>
                <p>
                                    <span style="color: #333">Y轴角度(°)：</span
                                    >{{ device.angleY }}
                </p>
                <p>
                                    <span style="color: #333">Z轴角度(°)：</span
                                    >{{ device.angleZ }}
                </p>
                <p>
                                    <span style="color: #333"
                                    >设备电压(v)：</span
                                    >{{ device.batteryVoltage }}
                </p>
              </template>
              <template v-if="tabActiveName == '3'">
                <p>
                                    <span style="color: #333"
                                    >气体浓度({{ device.unit_ }})：</span
                                    >{{ device.sdata }}
                </p>
              </template>
              <template v-if="tabActiveName == '2'">
                <p>
                                    <span style="color: #333"
                                    >水位高度(cm)：</span
                                    >{{ device.sdata }}
                </p>
              </template>
              <template v-if="tabActiveName == '4'">
                <p>
                                    <span style="color: #333"
                                    >升降柱最近的一次动作：</span
                                    >{{ device.lastActionName }}
                </p>
                <p>
                                    <span style="color: #333"
                                    >升降柱位置状态：</span
                                    >{{ device.statusName }}
                </p>
              </template>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>
  </div>
</template>

<script>
import signboardDevice from '@/api/device/signboardDevice.js'
import productManage from '@/api/device/productManage.js'
import req from '@/request.js'
import resourceManage from '@/api/device/resourceManage.js'
import equipmentIndex from '@/api/device/equipmentIndex.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'MobileDevice',
  data() {
    return {
      tabActiveName: '1',
      activeIds: [],
      activeChildrenIndex: 0,
      activeIndex: 0,
      policeList: [],
      treeData: [],
      treeChildrenData: [],
      queryParam: {
        pageBean: ''
      },
      interface: signboardDevice.signboaerdQuery,
      classList: [
        {text: '标识牌设备', value: '1'},
        {text: '危险源设备', value: '3'},
        {text: '积水设备', value: '2'},
        // {text: '防暴路障', value: '4'}
      ],
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'warnTime',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceCode',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'handleStatus',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warn.DEVICE_TYPE_',
          relation: 'AND',
          value: 1
        }
      ],
      page: 1,
      startPicker: false,
      statusData: {name: '', value: ''},
      title: '我的设备',
      currentUser: {},
      params: {
        trainingDate: ''
      },
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_', //图标预览
      columns: [], //产品列表
      startColumns: [],
      product: {
        name: '',
        id: ''
      },
      handleStatusList: [], //处理状态字典
      showPicker: false,
      deviceData: [],
      loading: false,
      finished: true,
      refreshing: false
    }
  },
  created() {
    this.handleStatusList = dictUtils.getDictItemsFromCache('clzt')
  },
  mounted() {
    this.currentUser = JSON.parse(sessionStorage.getItem('currentUser'))
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    this.onLoad()
  },
  methods: {
    onTabClick() {
      if (this.tabActiveName == '1') {
        this.interface = signboardDevice.signboaerdQuery
      }
      if (this.tabActiveName == '2') {
        this.interface = signboardDevice.waterQuery
      }
      if (this.tabActiveName == '3') {
        this.interface = signboardDevice.hazardQuery
      }
      if (this.tabActiveName == '4') {
        this.interface = signboardDevice.deviceDataBarricadeStatus
      }
      this.page = 1
      this.deviceData = []
      this.getDevice()
    },
    // 跳转设备详情
    handleDetail(item) {
      // this.$router.push({name: 'RealtimeData', query: {id: item.id}})
    },
    onCancel() {
      this.showPicker = false
    },
    onLoad() {
      setTimeout(() => {
        if (!this.loading) {
          this.getDevice()
        }
        console.log(999999999)
      }, 500)
    },
    onRefresh() {
      setTimeout(() => {
        this.page = 1
        this.refreshing = true
        this.deviceData = []
        this.getDevice()
      }, 500)
    },
    getDevice() {
      this.finished = false
      this.queryParam.pageBean = {pageSize: 20, page: this.page}
      // this.loading = true
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'createTime'
        }
      ]
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      this.interface(this.queryParam, (res) => {
        this.loading = false
        console.log(res, 'res', this.tabActiveName)

        if (this.tabActiveName == '3') {
          this.getUnit(res.rows)
        } else {
          this.deviceData.push(...res.rows)
        }

        console.log(this.deviceData)
        this.page++
        // 如果加载完毕，显示没有更多了
        if (this.deviceData.length >= res.total) {
          this.finished = true
        }
        setTimeout(() => {
          //code
          this.refreshing = false
        }, 1000)
      })
    },
    getUnit(data) {
      if (data.length) {
        data.forEach((item) => {
          let unitData = item['paramsValueList'].filter(
            (item) => item.confId == '1715250365881917440'
          )[0]
          if (unitData) {
            item.unit_ = unitData.value.split('-')[1]
          }
        })
        this.deviceData.push(...data)
      }
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

::v-deep .device .device-item-text[data-v-150a70fa] {
  border-bottom: 0;
}

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

.search-box {
  width: 100%;
  z-index: 10;
  // padding-top: 200px;
}

.treeDataLeft {
  //修改左侧宽度
  .van-tree-select__nav {
    flex: 1 !important;
  }

  .van-tree-select__content {
    flex: 1.6 !important;
  }
}

::v-deep .van-tabs__nav {
  background-color: #f9f9f9;
}

::v-deep .van-hairline--top::after {
  border-top-width: 0px;
}

.mobile-device {
  height: 100%;
  background-color: #f9f9f9;
}

.device {
  background-color: #f9f9f9;
  // margin-bottom: 6px;
  padding: 40px 40px 0 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  // display: flex;
  // align-items: center;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    height: auto;
    font-size: 50px;

    p {
      margin: 30px 0 30px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 0px 20px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 72px;
    }
  }

  .device-name {
    font-size: 72px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status .van-tag {
    // width: 300px;
    // padding: 4px 6px;
    // font-size: 12PX;
    width: 230px;
    border-radius: 5px;
    padding: 15px 5px;
    font-size: 55px;
    text-align: center;
    color: white;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}

.myStyle {
  padding: 40px 40px 40px 40px;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom.scss';
</style>
